# The Nerd Diary

[![pypi](https://img.shields.io/pypi/v/nerddiary.svg)](https://pypi.org/project/nerddiary/)
[![python](https://img.shields.io/pypi/pyversions/nerddiary.svg)](https://pypi.org/project/nerddiary/)
[![Build Status](https://github.com/mishamsk/nerddiary/actions/workflows/dev.yml/badge.svg)](https://github.com/mishamsk/nerddiary/actions/workflows/dev.yml)

TBD


* Documentation: <https://mishamsk.github.io/nerddiary>
* GitHub: <https://github.com/mishamsk/nerddiary>
* PyPI: <https://pypi.org/project/nerddiary/>
* Free software: Apache-2.0


## Features

* TODO

## Credits

This package was inspired by the [waynerv/cookiecutter-pypackage](https://github.com/waynerv/cookiecutter-pypackage) project template and others.
